@@ -56,7 +56,7 @@ class Config(BaseModel):
     """The blueprint for tgcf's whole config."""
 
     # pylint: disable=too-few-public-methods
-    admins: List[int] = []
+    admins: List[Union[int, str]] = []
     forwards: List[Forward] = []
     show_forwarded_from: bool = False
     live: LiveSettings = LiveSettings()
@@ -92,7 +92,7 @@ CONFIG_TYPE = detect_config_type()
 def read_config() -> Config:
     """Load the configuration defined by user."""
     if CONFIG_TYPE == 1:
-        with open(CONFIG_FILE_NAME) as file:
+        with open(CONFIG_FILE_NAME, encoding="utf8") as file:
             config_dict = yaml.full_load(file)
     elif CONFIG_TYPE == 2:
         config_env_var = os.getenv("TGCF_CONFIG")
@@ -116,7 +116,7 @@ def read_config() -> Config:
 def write_config(config: Config):
     """Write changes in config back to file."""
     if CONFIG_TYPE == 1 or CONFIG_TYPE == 0:
-        with open(CONFIG_FILE_NAME, "w") as file:
+        with open(CONFIG_FILE_NAME, "w", encoding="utf8") as file:
             yaml.dump(config.dict(), file, sort_keys=False, allow_unicode=True)
     elif CONFIG_TYPE == 2:
         logging.warning("Could not update config! As env var is used")
@@ -149,6 +149,10 @@ else:
 CONFIG = read_config()
 
 
+async def get_id(client: TelegramClient, peer):
+    return await client.get_peer_id(peer)
+
+
 async def load_from_to(
     client: TelegramClient, forwards: List[Forward]
 ) -> Dict[int, List[int]]:
@@ -171,7 +175,7 @@ async def load_from_to(
     from_to_dict = {}
 
     async def _(peer):
-        return await client.get_peer_id(peer)
+        return await get_id(client, peer)
 
     for forward in forwards:
         src = await _(forward.source)
@@ -180,6 +184,16 @@ async def load_from_to(
     return from_to_dict
 
 
+ADMINS = []
+
+
+async def load_admins(client: TelegramClient):
+    for admin in CONFIG.admins:
+        ADMINS.append(await get_id(client, admin))
+    logging.info(f"Loaded admins are {ADMINS}")
+    return ADMINS
+
+
 from_to = {}
 is_bot: Optional[bool] = None
 logging.info("config.py got executed")
